@@ -12,12 +12,13 @@ package Algorithm::Dependency::Ordered;
 # dependencies. For that reason, the schedule method will return an error
 # if a circular dependency is found.
 
+use 5.005;
 use strict;
 use base 'Algorithm::Dependency';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = 0.6;
+	$VERSION = '1.0';
 }
 
 
@@ -109,7 +110,7 @@ http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
 
 =head1 AUTHOR
 
-    Adam Kennedy
+    Adam Kennedy (Maintainer)
     cpan@ali.as
     http//ali.as/
 
@@ -119,7 +120,7 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Adam Kennedy. All rights reserved.
+Copyright (c) 2003 - 2004 Adam Kennedy. All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
